Welcome to |project| documentation!
===================================

.. toctree::
   :maxdepth: 1

   history

See the `workalendar docs <https://peopledoc.github.io/workalendar>`_
for more details.

.. automodule:: calendra
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

